#!/usr/bin/env python3
import configparser
import inquirer
import os
import sys
import click
import signal

@click.command()
def cli():
    signal.signal(signal.SIGINT, sig_handler)
    config_path = os.path.expanduser('~/.aws/config')
    credentials_path = os.path.expanduser('~/.aws/credentials')

    if not os.path.exists(config_path):
        sys.exit('''\nAWS config file (~/.aws/config) not found!
                \nRun \'aws configure --profile profile-name\' to configure your profiles!\n''')

    config = configparser.ConfigParser()
    config.read(config_path)
    credentials = configparser.ConfigParser()
    credentials.read(credentials_path)

    # Check if the user has set default profile 
    if 'default' in config.keys():
        # Check if the default profile was previously set by slapr
        if 'slapr' not in config['default'].keys():
            approve_step()

    # Configure inquirer to use the parsed configuration sections
    try:
        question = [
            inquirer.List(
                'selected_profile',
                message='Which AWS profile do you want to use?',
                choices=config.sections(),
                carousel=True
            )
        ]

        # Prompt the user to select the profile
        selected_profile = inquirer.prompt(question).get('selected_profile')
        # Remove profile 'profile ' from the selected profile
        credentials_profile = selected_profile.replace('profile ', '')
    # If ctrl+c is pressed here, it throws an AttributeError
    except AttributeError:
        sys.stdout.write('\b\b\r')
        sys.exit(0)

    # Inform user
    sys.stdout.write(f'\nSetting {credentials_profile} as default AWS profile.\n\n')

    # Set the default AWS Profile in teh config file
    config['default'] = config[selected_profile]
    # Set that the default profile is configured by slapr
    config['default']['slapr'] = 'True'
    with open(config_path, 'w') as configfile:
        config.write(configfile)
    # Omit SSO profiles as they don't have credentials
    if credentials_profile in credentials.sections():
        # Set the default AWS in the credentials file
        credentials['default'] = credentials[credentials_profile]
        with open(credentials_path, 'w') as credsfile:
            credentials.write(credsfile)

    # Check if account is SSO and inform user how to login
    if any('sso' in key for key in list(config[selected_profile].keys())):
        sys.stdout.write(f'Your AWS profile {credentials_profile} is using SSO.\n'
                        f'Please run \'aws sso login --profile {credentials_profile}\' to authenticate.\n')

# Handler function for the keyboard interrupt
def sig_handler(signum, stack):
    sys.stdout.write('\b\b\r')
    sys.exit('Cancelled by user')

# Function to prompt the user for approval
def approve_step():
    while True:
        approve = input(
                        f'\nYou have a configured default profile.\n'
                        f'Slapr will overwite it.\n'
                        f'Do you approve? y/n\n'
                        )
        if approve.strip()[:1].lower() == 'y' or approve.strip().lower() == 'yes':
            break
        if approve.strip()[:1].lower() == 'n' or approve.strip().lower() == 'no':
            sys.exit('Goodbye!')

if __name__ == '__main__':
    cli()



from setuptools import setup
# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()
setup(
  name = 'slapr',
  packages = ['slapr'],
  version = '1.3',
  license='gpl-3.0',
  description = 'A simple tool that allows you to change your default AWS CLI profile.',
  long_description=long_description,
  long_description_content_type='text/markdown',
  author = 'Antoni Yanev',
  author_email = 'antonipyanev@gmail.com',
  url = 'https://github.com/antonipy/slapr',
  download_url = 'https://github.com/antonipy/slapr/archive/refs/tags/1.3.tar.gz',
  keywords = ['aws', 'awscli', 'awscliv2', 'linux', 'tools'],
  install_requires=[
          'inquirer==2.8.0',
          'click==8.0.3'
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Intended Audience :: Developers',
    'Intended Audience :: System Administrators',
    'Topic :: Internet',
    'Topic :: Software Development :: Build Tools',
    'Topic :: Utilities',
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
  entry_points = '''
        [console_scripts]
        slapr=slapr.main:cli
    ''',
  include_package_data=True
)
